==> haskell-pandoc-lua-marshal-0.2.6-5.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-marshal
version:              0.2.6
visibility:           public
id:                   pandoc-lua-marshal-0.2.6-8NA6OCjPpAKI1SOd8O5WUN
key:                  pandoc-lua-marshal-0.2.6-8NA6OCjPpAKI1SOd8O5WUN
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  c35d64c0f25cbad7e3988406020e6401
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-marshal-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.6-8NA6OCjPpAKI1SOd8O5WUN
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 exceptions-0.10.4
    hslua-2.3.0-EQeElTppdO0EglsvALVWWe
    hslua-list-1.1.1-BwXdIQy3ckEK6raha9vMM5
    hslua-marshalling-2.3.1-KsyI9r2uX5jHis6xOiGZDK
    pandoc-types-1.23.1-9zMZjeuwTZD9DvwIlvEps5
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-marshal-0.2.7-49.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-marshal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-marshal
version:              0.2.7
visibility:           public
id:                   pandoc-lua-marshal-0.2.7-jvOYnyhHE95GubwrcwvgN
key:                  pandoc-lua-marshal-0.2.7-jvOYnyhHE95GubwrcwvgN
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel, John MacFarlane
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel, John MacFarlane
homepage:             https://github.com/pandoc/pandoc-lua-marshal
synopsis:             Use pandoc types in Lua
description:
    This package provides functions to marshal and unmarshal
    pandoc document types to and from Lua.

    The values of most types are pushed to pandoc as "userdata"
    objects that wrap a stable pointer to the Haskell value;
    these objects come with methods to access and modify their
    properties.

    Sequences are pushed as normal Lua tables, but are
    augmented with convenience functions.

category:             Foreign
abi:                  76629f77a2da3b2492c00243f35ce5cb
exposed:              True
exposed-modules:
    Text.Pandoc.Lua.Marshal.AST Text.Pandoc.Lua.Marshal.Alignment
    Text.Pandoc.Lua.Marshal.Attr Text.Pandoc.Lua.Marshal.Block
    Text.Pandoc.Lua.Marshal.Cell Text.Pandoc.Lua.Marshal.Citation
    Text.Pandoc.Lua.Marshal.CitationMode
    Text.Pandoc.Lua.Marshal.Content Text.Pandoc.Lua.Marshal.Filter
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.Inline
    Text.Pandoc.Lua.Marshal.List Text.Pandoc.Lua.Marshal.ListAttributes
    Text.Pandoc.Lua.Marshal.MathType Text.Pandoc.Lua.Marshal.MetaValue
    Text.Pandoc.Lua.Marshal.Pandoc Text.Pandoc.Lua.Marshal.QuoteType
    Text.Pandoc.Lua.Marshal.Row Text.Pandoc.Lua.Marshal.SimpleTable
    Text.Pandoc.Lua.Marshal.TableFoot Text.Pandoc.Lua.Marshal.TableHead
    Text.Pandoc.Lua.Marshal.TableParts

hidden-modules:
    Text.Pandoc.Lua.Marshal.Shared Text.Pandoc.Lua.Topdown
    Text.Pandoc.Lua.SpliceList Text.Pandoc.Lua.Walk

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-lua-marshal-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-marshal
hs-libraries:         HSpandoc-lua-marshal-0.2.7-jvOYnyhHE95GubwrcwvgN
depends:
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 exceptions-0.10.5
    hslua-2.3.0-H2gnlG2mrpf6kupCvqYKRA
    hslua-list-1.1.3-9t9Iu5m9DfF6fTNhCVFpXw
    hslua-marshalling-2.3.1-De1Uoy5VWhRDIpPMRqEvHW
    pandoc-types-1.23.1-2r8yaaO6zUGIu9l6jrpe8t
    safe-0.3.21-9t18UaHoT5jA6SQBJagYvS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-marshal/html/pandoc-lua-marshal.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-marshal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
